pub struct MaterialReplacementWhenSceneReadyComponent {
pub material_replacements: HashMap<String, String>,
}Fields
material_replacements: HashMap<String, String>Trait Implementations
Sourceimpl Component for MaterialReplacementWhenSceneReadyComponent
impl Component for MaterialReplacementWhenSceneReadyComponent
Sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.Auto Trait Implementations
impl Freeze for MaterialReplacementWhenSceneReadyComponent
impl RefUnwindSafe for MaterialReplacementWhenSceneReadyComponent
impl Send for MaterialReplacementWhenSceneReadyComponent
impl Sync for MaterialReplacementWhenSceneReadyComponent
impl Unpin for MaterialReplacementWhenSceneReadyComponent
impl UnsafeUnpin for MaterialReplacementWhenSceneReadyComponent
impl UnwindSafe for MaterialReplacementWhenSceneReadyComponent